@@ -2,7 +2,7 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2019 by The BRLTTY Developers.
+ * Copyright (C) 1995-2020 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
@@ -208,7 +208,7 @@ typedef enum {
   BRL_CMD_CLIP_SAVE /* save clipboard to disk */,
   BRL_CMD_CLIP_RESTORE /* restore clipboard from disk */,
 
-  BRL_CMD_BRLUCDOTS /* set braille input mode dots/text */,
+  BRL_CMD_BRLUCDOTS /* set braille typing mode dots/text */,
   BRL_CMD_BRLKBD /* set braille keyboard enabled/disabled */,
 
   BRL_CMD_UNSTICK /* clear all sticky input modifiers */,
@@ -233,6 +233,8 @@ typedef enum {
   BRL_CMD_SPEAK_INDENT /* speak indent of current line */,
   BRL_CMD_ASPK_INDENT /* set autospeak indent of current line on/off */,
 
+  BRL_CMD_REFRESH /* refresh braille display */,
+
   BRL_basicCommandCount /* must be last */
 } BRL_BasicCommand;
 
@@ -265,8 +267,8 @@ typedef enum {
   BRL_BLK_SET_CONTRACTION_TABLE /* set contraction table */,
   BRL_BLK_SET_KEYBOARD_TABLE /* set keyboard table */,
   BRL_BLK_SET_LANGUAGE_PROFILE /* set language profile */,
-  BRL_BLK_18 /* (reserved) */,
-  BRL_BLK_19 /* (reserved) */,
+  BRL_BLK_ROUTE_LINE /* bring screen cursor to line */,
+  BRL_BLK_REFRESH_LINE /* refresh braille line */,
   BRL_BLK_1A /* (reserved) */,
   BRL_BLK_1B /* (reserved) */,
   BRL_BLK_1C /* (reserved) */,
